@@ -1,5 +1,5 @@
-import sys
 import argparse
+import sys
 
 
 class frozendict:
@@ -13,9 +13,7 @@ class frozendict:
         return self.repo[item]
 
     def __setitem__(self, key, value):
-        raise TypeError(
-            f"frozendict object does not support updating"
-        )
+        raise TypeError(f"frozendict object does not support updating")
 
 
 def shift_lst(lst: list, move_forward):
@@ -26,6 +24,3 @@ if sys.version_info.major >= 3 and sys.version_info.minor >= 8:
     from deep_utils.utils.utils.dictnamedtuple_38 import dictnamedtuple
 else:
     from deep_utils.utils.utils.dictnamedtuple_37 import dictnamedtuple
-
-
-
