@@ -1,3 +1,5 @@
 from .face_detection import *
 from .object_detection import *
 from .object_tracker import *
+from .torch_vision import *
+from .face_recognition import *
