@@ -4,7 +4,7 @@ import torch
 
 
 def str2bool(s):
-    return s.lower() in ('true', '1')
+    return s.lower() in ("true", "1")
 
 
 class Timer:
@@ -20,18 +20,23 @@ class Timer:
         interval = datetime.datetime.now() - self.clock[key]
         del self.clock[key]
         return interval.total_seconds()
-        
 
-def save_checkpoint(epoch, net_state_dict, optimizer_state_dict, best_score, checkpoint_path, model_path):
-    torch.save({
-        'epoch': epoch,
-        'model': net_state_dict,
-        'optimizer': optimizer_state_dict,
-        'best_score': best_score
-    }, checkpoint_path)
+
+def save_checkpoint(
+    epoch, net_state_dict, optimizer_state_dict, best_score, checkpoint_path, model_path
+):
+    torch.save(
+        {
+            "epoch": epoch,
+            "model": net_state_dict,
+            "optimizer": optimizer_state_dict,
+            "best_score": best_score,
+        },
+        checkpoint_path,
+    )
     torch.save(net_state_dict, model_path)
-        
-        
+
+
 def load_checkpoint(checkpoint_path):
     return torch.load(checkpoint_path)
 
